import pickle

from elasticsearch7_dsl import utils, serializer

from pytest import raises

def test_attrdict_pickle():
    ad = utils.AttrDict({})

    pickled_ad = pickle.dumps(ad)
    assert ad == pickle.loads(pickled_ad)


def test_attrlist_pickle():
    al = utils.AttrList([])

    pickled_al = pickle.dumps(al)
    assert al == pickle.loads(pickled_al)

def test_attrlist_slice():
    class MyAttrDict(utils.AttrDict):
        pass

    l = utils.AttrList([{}, {}], obj_wrapper=MyAttrDict)
    assert isinstance(l[:][0], MyAttrDict)

def test_merge():
    a = utils.AttrDict({'a': {'b': 42, 'c': 47}})
    b = {'a': {'b': 123, 'd': -12}, 'e': [1, 2, 3]}

    utils.merge(a, b)

    assert a == {'a': {'b': 123, 'c': 47, 'd': -12}, 'e': [1, 2, 3]}

def test_merge_conflict():
    for d in ({'a': 42}, {'a': {'b': 47}},):
        utils.merge({'a': {'b': 42}}, d)
        with raises(ValueError):
            utils.merge({'a': {'b': 42}}, d, True)

def test_attrdict_bool():
    d = utils.AttrDict({})

    assert not d
    d.title = 'Title'
    assert d

def test_attrlist_items_get_wrapped_during_iteration():
    al = utils.AttrList([1, object(), [1], {}])

    l = list(iter(al))

    assert isinstance(l[2], utils.AttrList)
    assert isinstance(l[3], utils.AttrDict)

def test_serializer_deals_with_Attr_versions():
    d = utils.AttrDict({'key': utils.AttrList([1, 2, 3])})

    assert serializer.serializer.dumps(d) == serializer.serializer.dumps({'key': [1, 2, 3]})

def test_serializer_deals_with_objects_with_to_dict():
    class MyClass(object):
        def to_dict(self):
            return 42

    assert serializer.serializer.dumps(MyClass()) == '42'
